@@ -9,25 +9,30 @@ def simple_isnan(item):
     except ValueError:
         return True
 
-def _get_help(cmd=""):
+def _get_help(cmd="", *args, **kwargs):
     help_menu = HelpMenu()
-    help_menu.get(cmd)
+    help_menu.get(cmd, *args, **kwargs)
     sys.exit()
 
 def reader():
     cmd = sys.argv[1]
     args = sys.argv[2::]
+    kwargs = {}
+
     if cmd in ("-h", "--help"):
         return _get_help()
     elif any(h in args for h in ("-h", "--help")):
         return _get_help(cmd)
-    kwargs = {}
+        
     kwarg_keys = reversed([
         index for index, item in enumerate(args) 
         if (item.startswith('-') and simple_isnan(item))
     ])
     for k in kwarg_keys:
-        value = args.pop(k+1)
+        try:
+            value = args.pop(k+1)
+        except IndexError:
+            value = True
         key = args.pop(k)
         kwargs[key] = value
 
